==> cresce_ui-0.7.4.tar.gz: test/cresce_ui_test.dart <==
import 'package:cresce_ui/cresce_ui.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:golden_toolkit/golden_toolkit.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  testGoldens('CHeader screen test', (tester) async {
    const builder = CHeader(title: 'Cresce');

    await tester.pumpWidgetBuilder(builder);

    await screenMatchesGolden(tester, 'CHeader');
  });

  testGoldens('CInputDropdown screen test', (tester) async {
    var builder = DeviceBuilder()
      ..overrideDevicesForAllScenarios(devices: [Device.iphone11])
      ..addScenario(
        name: 'empty',
        widget: const CInputDropdown(
          label: 'User',
          items: [],
        ),
      )
      ..addScenario(
        name: 'closed',
        widget: const CInputDropdown(
          label: 'User',
          items: [
            "option 1",
            "option 2",
            "option 3",
          ],
        ),
      )
      ..addScenario(
        name: 'opened',
        widget: const CInputDropdown<String>(
          label: 'User',
          items: [
            "option 1",
            "option 2",
            "option 3",
          ],
        ),
        onCreate: (scenarioWidgetKey) async {
          await tester.tap(find.byKey(scenarioWidgetKey));
        },
      );

    await tester.pumpDeviceBuilder(builder);

    await screenMatchesGolden(tester, 'CInputDropdown');
  });

  testGoldens('CModalHeader screen test', (tester) async {
    const builder = Center(
      child: CModalHeader(title: 'Isabel Rodrigues', subTitle: ''),
    );

    await tester.pumpWidgetBuilder(builder);

    await screenMatchesGolden(tester, 'CModalHeader');
  });

  testGoldens('CDataSelected screen test', (tester) async {
    final builder = GoldenBuilder.grid(columns: 2, widthToHeightRatio: 1)
      ..addScenario(
        'Title',
        const CDataSelected(label: 'TestEmployee'),
      )
      ..addScenario(
        'Title & SubTitle',
        const CDataSelected(label: 'Cresce'),
      );

    await tester.pumpWidgetBuilder(builder.build());

    await screenMatchesGolden(tester, 'CDataSelected');
  });

  testGoldens('CThumbnail screen test', (tester) async {
    final builder = GoldenBuilder.column()
      ..addScenario(
        'Title',
        const CThumbnail(title: 'Cresce'),
      )
      ..addScenario(
        'Big Title',
        const CThumbnail(
          title:
              'Big Title - This is a very big title. This is a very big title.',
        ),
      )
      ..addScenario(
        'Big Title Truncated',
        const CThumbnail(
          title:
              'Big Title - This is a very big title. This is a very big title. This is a very big title. This is a very big title. This is a very big title.',
          maxTitleLength: 50,
        ),
      )
      ..addScenario(
        'Title & SubTitle',
        const CThumbnail(title: 'Title', subTitle: 'some subTitle'),
      );

    await tester.pumpWidgetBuilder(builder.build(),
        surfaceSize: const Size(200, 1600));

    await screenMatchesGolden(tester, 'CThumbnail', autoHeight: true);
  });

  testGoldens('CThumbnailBalance screen test', (tester) async {
    final builder = GoldenBuilder.column()
      ..addScenario(
        'Title',
        const CThumbnailBalance(
          title: 'Title',
          balance: '100.3',
        ),
      )
      ..addScenario(
        'Big Title Truncated',
        const CThumbnailBalance(
          title:
              'Big Title - This is a very big title. This is a very big title. This is a very big title. This is a very big title. This is a very big title.',
          balance: '100.3',
        ),
      )
      ..addScenario(
        'Big Title With Big words Truncated',
        const CThumbnailBalance(
          title: 'ADMCD - ThisIsABigWord ThisIsAnotherBigWord',
          balance: '100.3',
        ),
      );

    await tester.pumpWidgetBuilder(builder.build(),
        surfaceSize: const Size(200, 1600));

    await screenMatchesGolden(tester, 'CThumbnailBalance', autoHeight: true);
  });
}

==> cresce_ui-0.8.6.tar.gz: test/cresce_ui_test.dart <==
import 'package:cresce_ui/cresce_ui.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:golden_toolkit/golden_toolkit.dart';

void main() {
  testGoldens('CHeader screen test', (tester) async {
    const builder = CHeader(title: 'Cresce');

    await tester.pumpWidgetBuilder(builder);

    await screenMatchesGolden(tester, 'CHeader');
  });

  testGoldens('CInputDropdown screen test', (tester) async {
    var builder = DeviceBuilder()
      ..overrideDevicesForAllScenarios(devices: [Device.iphone11])
      ..addScenario(
        name: 'empty',
        widget: const CInputDropdown(
          label: 'User',
          items: [],
        ),
      )
      ..addScenario(
        name: 'closed',
        widget: const CInputDropdown(
          label: 'User',
          items: [
            "option 1",
            "option 2",
            "option 3",
          ],
        ),
      )
      ..addScenario(
        name: 'opened',
        widget: CInputDropdown<String>(
          label: 'User',
          items: const [
            "option 1",
            "option 2",
            "option 3",
          ],
          onChanged: (value) {
            print(value);
          },
        ),
        onCreate: (scenarioWidgetKey) async {
          await tester.tap(find.byKey(scenarioWidgetKey));
        },
      );

    await tester.pumpDeviceBuilder(builder);

    await screenMatchesGolden(tester, 'CInputDropdown');
  });

  testGoldens('CModalHeader screen test', (tester) async {
    const builder = Center(
      child: CModalHeader(title: 'Isabel Rodrigues', subTitle: ''),
    );

    await tester.pumpWidgetBuilder(builder);

    await screenMatchesGolden(tester, 'CModalHeader');
  });

  testGoldens('CDataSelected screen test', (tester) async {
    final builder = GoldenBuilder.grid(columns: 2, widthToHeightRatio: 1)
      ..addScenario(
        'Title',
        const CDataSelected(label: 'TestEmployee'),
      )
      ..addScenario(
        'Title & SubTitle',
        const CDataSelected(label: 'Cresce'),
      );

    await tester.pumpWidgetBuilder(builder.build());

    await screenMatchesGolden(tester, 'CDataSelected');
  });

  testGoldens('CThumbnail screen test', (tester) async {
    final builder = GoldenBuilder.column()
      ..addScenario(
        'Title',
        const CThumbnail(title: 'Cresce'),
      )
      ..addScenario(
        'Big Title',
        const CThumbnail(
          title:
              'Big Title - This is a very big title. This is a very big title.',
        ),
      )
      ..addScenario(
        'Big Title Truncated',
        const CThumbnail(
          title:
              'Big Title - This is a very big title. This is a very big title. This is a very big title. This is a very big title. This is a very big title.',
          maxTitleLength: 50,
        ),
      )
      ..addScenario(
        'Title & SubTitle',
        const CThumbnail(title: 'Title', subTitle: 'some subTitle'),
      );

    await tester.pumpWidgetBuilder(builder.build(),
        surfaceSize: const Size(200, 1600));

    await screenMatchesGolden(tester, 'CThumbnail', autoHeight: true);
  });

  testGoldens('CThumbnailBalance screen test', (tester) async {
    final builder = GoldenBuilder.column()
      ..addScenario(
        'Title',
        const CThumbnailBalance(
          title: 'Title',
          balance: '100.3',
        ),
      )
      ..addScenario(
        'Big Title Truncated',
        const CThumbnailBalance(
          title:
              'Big Title - This is a very big title. This is a very big title. This is a very big title. This is a very big title. This is a very big title.',
          balance: '100.3',
        ),
      )
      ..addScenario(
        'Big Title With Big words Truncated',
        const CThumbnailBalance(
          title: 'ADMCD - ThisIsABigWord ThisIsAnotherBigWord',
          balance: '100.3',
        ),
      );

    await tester.pumpWidgetBuilder(builder.build(),
        surfaceSize: const Size(200, 1600));

    await screenMatchesGolden(tester, 'CThumbnailBalance', autoHeight: true);
  });
}
